==> groupoffice-com-4.0.97.tar.gz: groupoffice-com-4.0.97/modules/email/language/fr.js <==
/////////////////////////////////////////////////////////////////////////////////
//
// Copyright Intermesh
// 
// This file is part of Group-Office. You should have received a copy of the
// Group-Office license along with Group-Office. See the file /LICENSE.TXT
// 
// If you have questions write an e-mail to info@intermesh.nl
//
// @copyright Copyright Intermesh
// @version $Id: fr.js 8287 2011-10-12 12:03:09Z mschering $
// @author Merijn Schering <mschering@intermesh.nl>
//
// French Translation
// Version : 3.7.29 
// Author : Lionel JULLIEN
// Date : September, 27 2011
//
/////////////////////////////////////////////////////////////////////////////////
 
GO.email.lang.forwardTo='Transférer le message à';
GO.email.lang.messages='Messages';
GO.email.lang.message='Message';
GO.email.lang.inbox='Boite de réception';
GO.email.lang.accounts='Comptes de messagerie';
GO.email.lang.account='Compte de messagerie';
GO.email.lang.crossAccountMove='Désolé, il est impossible de déplacer les messages vers un autre compte';
GO.email.lang.compose='Composer';
GO.email.lang.reply='Répondre';
GO.email.lang.replyAll='Répondre à tous';
GO.email.lang.forward='Faire suivre';
GO.email.lang.markAsRead='Marqué comme lu';
GO.email.lang.markAsUnread='Marqué comme non lu';
GO.email.lang.flag='Ajouter un marqueur';
GO.email.lang.unflag='Enlever un marqueur';
GO.email.lang.flagged='Marqué';
GO.email.lang.unflagged='Non marqué';
GO.email.lang.root='Racine';
GO.email.lang.folders='Dossiers';
GO.email.lang.filter='Filtre';
GO.email.lang.filters='Filtres';
GO.email.lang.selectFolderDelete='Sélectionnez un dossier à supprimer';
GO.email.lang.selectFolderAdd='Sélectionnez un dossier (dans l\'arborescence) dans lequel vous voulez créer le nouveau dossier. Cliquez ensuite sur \'Ajouter\'';
GO.email.lang.forward='Faire suivre';
GO.email.lang.resetSearch='Réinitialiser la recherche';
GO.email.lang.emailMessage='Message';
GO.email.lang.host='Hôte';
GO.email.lang.field='Champs';
GO.email.lang.contains='Contient';
GO.email.lang.moveToFolder='Déplacer vers le dossier';
GO.email.lang.incomingMail='Messages entrant';
GO.email.lang.advanced='Avancé';
GO.email.lang.ssl='SSL';
GO.email.lang.tls='TLS';
GO.email.lang.novalidateCert='Ne pas valider le certificat';
GO.email.lang.port='Port';
GO.email.lang.rootMailbox='Racine de la boite';
GO.email.lang.manageFolders='Gérer les dossiers';
GO.email.lang.sendItemsFolder='Eléments envoyés';
GO.email.lang.trashFolder='Corbeille';
GO.email.lang.draftsFolder='Brouillons';
GO.email.lang.sender='Champs - De';
GO.email.lang.subject='Sujet';
GO.email.lang.toField='Champs - A';
GO.email.lang.ccField='Champs - CC (Copie)';
GO.email.lang.bccField='Champs - BCC (Copie cachée)';
GO.email.lang.keyword='Mot clé';
GO.email.lang.notification='Demander une notification de lecture';
GO.email.lang.high='Haute';
GO.email.lang.normal='Normale';
GO.email.lang.low='Basse';
GO.email.lang.from='De';
GO.email.lang.sendTo='Envoyé à';
GO.email.lang.cc='Copie';
GO.email.lang.bcc='Copie cachée';
GO.email.lang.selectTemplate='Sélectionnez un modèle';
GO.email.lang.composeEmail='Composer un message';
GO.email.lang.send='Envoyer';
GO.email.lang.extraOptions='Options supplémentaires';
GO.email.lang.attachments='Pièces jointes';
GO.email.lang.show='Montrer';
GO.email.lang.noAccount='Vous n\'avez pas encore configuré de compte e-mail. Allez dans le module E-mail -> Comptes afin de configurer votre premier compte e-mail';
GO.email.lang.attachFiles='Joindre un fichier depuis votre ordinateur';
GO.email.lang.uploadAttachments='Télécharger les pièces jointes';
GO.email.lang.startTransfer='Débuter le transfert';
GO.email.lang.cantEditFolder='Vous ne pouvez pas éditer ce dossier';
GO.email.lang.cantDeleteInboxFolder='Vous ne pouvez pas supprimer le dossier \'Boite de réception\'';
GO.email.lang.enterFolderName='Saisissez le nom du dossier :';
GO.email.lang.addFolder='Ajouter un dossier';
GO.email.lang.to='A';
GO.email.lang.downloadAllAsZip='Télécharger toutes les pièces jointes dans un fichier ZIP';
GO.email.lang.body='Corps';
GO.email.lang.recievedBefore='Reçu avant';
GO.email.lang.recievedSince='Reçu depuis';
GO.email.lang.answered='Répondu';
GO.email.lang.unanswered='Non répondu';
GO.email.lang.viewed='Vu';
GO.email.lang.outgoingMail='Messages sortant';
GO.email.lang.encryption='Cryptage';
GO.email.lang.type='Type';
GO.email.lang.noEncryption='Pas de cryptage';
GO.email.lang.noAccountTitle='Pas de compte';
GO.email.lang.priority='Priorité';
GO.email.lang.read='Lu';
GO.email.lang.NA='N/R';
GO.email.lang.emptyFolder='Vider ce dossier';
GO.email.lang.emptyFolderConfirm='Etes-vous sûr de vouloir <font style="color: red;">VIDER</font> le dossier <b>\'{name}\'</b> ?';
GO.email.lang.addUnknownRecipients='Ajouter les destinataires inconnus';
GO.email.lang.addUnknownRecipientsText='Vous venez juste d\'envoyer un message à un destinataire qui ne figure pas dans votre carnet d`adresses. Cliquez sur le nom si vous voulez l\'ajouter ou fermez cette fenêtre.';
GO.email.lang.attachFilesPC='Ajouter depuis votre ordinateur';
GO.email.lang.attachFilesGO='Ajouter depuis Group-Office';
GO.email.lang.renameFolder='Renommer ce dossier';
GO.email.lang.vacation='Réponse automatique';
GO.email.lang.vacationActive='Activer la réponse automatique';
GO.email.lang.vacationSubject='Sujet';
GO.email.lang.vacationBody='Corps';
GO.email.lang.addToRecipients = 'Ajouter aux destinataires';
GO.email.lang.addToCC = 'Ajouter en copie';
GO.email.lang.addToBCC = 'Ajouter en copie cachée';
GO.email.lang.viewSource='Voir la source du message';
GO.email.lang.sendNotification='L\'expéditeur de ce message a demandé une notification de lecture : %s. Voulez-vous envoyer la notification maintenant ?';
GO.email.lang.searchOnSender='Afficher les messages';
GO.email.lang.blocked = '{blocked_images} Afin de protéger votre vie privée, l\'affichage des images distantes a été bloqué.';
GO.email.lang.unblock = 'Cliquez ici pour afficher les images bloquées';
GO.email.lang.loadEmailFirst = 'Pour utiliser cette fonctionnalité vous devez tout d\'abord cliquer sur l\'onglet e-mail';
GO.email.lang.confirmEmptySubject='Vous n\'avez pas spécifié de sujet à votre message.\nVoulez-vous quand même l\'envoyer ?';
GO.email.lang.usage='Espace utilisé';
GO.email.lang.searchGO='Recherche globale';
GO.email.lang.toggleWindowPosition = 'Permuter l\'affichage des messages';
GO.email.lang.closeUploadDialog='Veuillez fermer cette fenêtre ou attendre la fin du transfert';
GO.email.lang.signature='Signature';
GO.email.defaultProgram='Programme de messagerie par défaut';
GO.email.defaultProgramInstructions ='<p>Pour définir Group-Office comme programme de messagerie par défaut, veuillez <a class="normal-link" href="http://www.group-office.com/wiki/E-mail#Set_Group-Office_as_your_default_e-mail_client" target="_blank">lire ces instructions</a>.</p><p>Si vous utilisez Microsoft Windows, vous devez télécharger et exécuter <a class="normal-link" href="{url}">ce fichier</a></p>';
GO.email.lang.htmlMarkup = 'Rédiger en HTML';
GO.email.lang.confirmLostChanges = 'Changer d\'éditeur entraîne la perte du texte de votre message !\nVoulez-vous continuer ?';
/* table: em_aliases */
GO.email.lang.alias="Paramètres de l'identité";
GO.email.lang.aliases="Identités multiples";
GO.email.lang.accountId="ID du compte";
GO.email.lang.email="E-mail";
GO.email.lang.signature="Signature";
GO.email.lang.manageAliases='Gérer les identités...';
GO.email.lang.addSendersTo='Nouveau message à l\'expéditeur';
GO.email.lang.defaultTemplate='Sélectionner ce modèle par défaut';
GO.email.lang.moving='Déplacement...';
GO.email.lang.orderFilters='Vous pouvez déplacer l\'ordre des filtres en cliquant / déplaçant.';
GO.email.lang.orderAccounts='Vous pouvez déplacer l\'ordre des comptes en cliquant / déplaçant.';
GO.email.lang.groups='Groupes';
GO.email.lang.showUnread='Afficher les messages non lus';
GO.email.lang.searchFrom='Expéditeur';
GO.email.lang.searchTo='Destinataire';
GO.email.lang.searchCC='Destinataire (CC)';
GO.email.lang.youHaveNewMails = 'Vous avez {new} nouveau(x) message(s)';
GO.email.lang.anyField='Tous les champs';

GO.email.lang.selectFolderRename='Veuillez sélectionner un dossier a renommer';
GO.email.lang.cantRenameInboxFolder='Vous ne pouvez pas renommer le dossier Boite de réception';
GO.email.lang.replaceEmailText='Trois adresses email sont déjà assignées a ce contact. Vous pouvez remplacer une adresse existante ci-dessous en cliquant sur l\'adresse que vous souhaitez remplacer.';
GO.email.lang.skipUnknownRecipientsAction='Ne pas afficher cette fenêtre la prochaine fois';
GO.email.lang.skipUnknownRecipients='Ne pas afficher de boite de dialogue pour les destinaires inconnus';
GO.email.lang.alwaysRequestNotification='Toujours demander un accusé de réception';
GO.email.lang.alwaysRespondToNotifications='Toujours répondre aux accusés de réception';
GO.email.lang.icalendarUpdateEvent='Mettre à jour le rendez vous';
GO.email.lang.icalendarDeleteEvent='Supprimer le rendez-vous';
GO.email.lang.icalendarAcceptInvitation='Accepter';
GO.email.lang.icalendarDeclineInvitation='Décliner';
GO.email.lang.icalendarTentativeInvitation='Accepter sous réserve';
GO.email.lang.icalendarEventUpdated='Le rendez-vous a été mis à jour.';
GO.email.lang.icalendarEventCreated='Le rendez-vous a été créé.';
GO.email.lang.icalendarEventDeleted='Le rendez-vous a été supprimé.';
GO.email.lang.icalendarInvitationDeclined='L\'invitation a été déclinée.';
GO.email.lang.icalendarDeleteEventConfirm='Êtes vous sur de vouloir supprimer ce rendez-vous ?';
GO.email.lang.sending='Envoi en cours...';

GO.email.lang.defaultFontSize = 'Taille de la police par défaut';
GO.email.lang.shareFolder = 'Partager';
GO.email.lang.readPerm='Lire';
GO.email.lang.writePerm='Ecrire';
GO.email.lang.deletePerm='supprimer';
GO.email.lang.createMailboxPerm='Créer la boite de messagerie';
GO.email.lang.deleteMailboxPerm='Supprimer la boite messagerie';
GO.email.lang.adminPerm='Administrer';

GO.email.lang.deleteOldMails = 'Supprimer les anciens messages';
GO.email.lang.deleteOldMailsInstructions = 'Sélectionnez une date. Si vous cliquez sur OK, tous les messages avec une date antérieure dans le dossier sélectionné seront supprimés.';
GO.email.lang.folder = 'Dossier';
GO.email.lang.deleteOldMailsSure1 = 'Cette action est irréversible. Etes-vous sûr de vouloir supprimer tous les messages remplissant la condition de date selectionnée ';
GO.email.lang.deleteOldMailsSure2 = '?'
GO.email.lang.nDeletedMailsTxt = 'Le nombre de messages supprimés est';
GO.email.lang.deletingEmails = 'Suppression des messages...';
GO.email.lang.everythingBefore = 'Tous les messages avant';
GO.email.lang.alsoChildren = 'Appliquer également cette condition aux sous-dossiers.';

==> groupoffice-com-4.0.144.tar.gz: groupoffice-com-4.0.144/modules/email/language/fr.js <==
/////////////////////////////////////////////////////////////////////////////////
//
// Copyright Intermesh
// 
// This file is part of Group-Office. You should have received a copy of the
// Group-Office license along with Group-Office. See the file /LICENSE.TXT
// 
// If you have questions write an e-mail to info@intermesh.nl
//
// @copyright Copyright Intermesh
// @version $Id: fr.js 12014 2012-09-20 16:01:48Z mschering $
// @author Merijn Schering <mschering@intermesh.nl>
//
// French Translation
// Version : 4.0.99
// Author : Lionel JULLIEN / Boris HERBINIERE-SEVE
// Date : September, 20 2012
//
/////////////////////////////////////////////////////////////////////////////////
 
GO.email.lang.forwardTo='Transférer le message à';
GO.email.lang.messages='Messages';
GO.email.lang.message='Message';
GO.email.lang.inbox='Boite de réception';
GO.email.lang.accounts='Comptes de messagerie';
GO.email.lang.account='Compte de messagerie';
GO.email.lang.crossAccountMove='Désolé, il est impossible de déplacer les messages vers un autre compte';
GO.email.lang.compose='Composer';
GO.email.lang.reply='Répondre';
GO.email.lang.replyAll='Répondre à tous';
GO.email.lang.forward='Faire suivre';
GO.email.lang.markAsRead='Marqué comme lu';
GO.email.lang.markAsUnread='Marqué comme non lu';
GO.email.lang.flag='Ajouter un marqueur';
GO.email.lang.unflag='Enlever un marqueur';
GO.email.lang.flagged='Marqué';
GO.email.lang.unflagged='Non marqué';
GO.email.lang.root='Racine';
GO.email.lang.folders='Dossiers';
GO.email.lang.filter='Filtre';
GO.email.lang.filters='Filtres';
GO.email.lang.selectFolderDelete='Sélectionnez un dossier à supprimer';
GO.email.lang.selectFolderAdd='Sélectionnez un dossier (dans l\'arborescence) dans lequel vous voulez créer le nouveau dossier. Cliquez ensuite sur \'Ajouter\'';
GO.email.lang.forward='Faire suivre';
GO.email.lang.resetSearch='Réinitialiser la recherche';
GO.email.lang.emailMessage='Message';
GO.email.lang.host='Hôte';
GO.email.lang.field='Champs';
GO.email.lang.contains='Contient';
GO.email.lang.moveToFolder='Déplacer vers le dossier';
GO.email.lang.incomingMail='Messages entrant';
GO.email.lang.advanced='Avancé';
GO.email.lang.ssl='SSL';
GO.email.lang.tls='TLS';
GO.email.lang.novalidateCert='Ne pas valider le certificat';
GO.email.lang.port='Port';
GO.email.lang.rootMailbox='Racine de la boite';
GO.email.lang.manageFolders='Gérer les dossiers';
GO.email.lang.sendItemsFolder='Eléments envoyés';
GO.email.lang.trashFolder='Corbeille';
GO.email.lang.draftsFolder='Brouillons';
GO.email.lang.sender='Champs - De';
GO.email.lang.subject='Sujet';
GO.email.lang.toField='Champs - A';
GO.email.lang.ccField='Champs - CC (Copie)';
GO.email.lang.bccField='Champs - BCC (Copie cachée)';
GO.email.lang.keyword='Mot clé';
GO.email.lang.notification='Demander une notification de lecture';
GO.email.lang.high='Haute';
GO.email.lang.normal='Normale';
GO.email.lang.low='Basse';
GO.email.lang.from='De';
GO.email.lang.sendTo='Envoyé à';
GO.email.lang.cc='Copie';
GO.email.lang.bcc='Copie cachée';
GO.email.lang.selectTemplate='Sélectionnez un modèle';
GO.email.lang.composeEmail='Composer un message';
GO.email.lang.send='Envoyer';
GO.email.lang.extraOptions='Options supplémentaires';
GO.email.lang.attachments='Pièces jointes';
GO.email.lang.show='Montrer';
GO.email.lang.noAccount='Vous n\'avez pas encore configuré de compte e-mail. Allez dans le module E-mail -> Comptes afin de configurer votre premier compte e-mail';
GO.email.lang.attachFiles='Joindre un fichier depuis votre ordinateur';
GO.email.lang.uploadAttachments='Télécharger les pièces jointes';
GO.email.lang.startTransfer='Débuter le transfert';
GO.email.lang.cantEditFolder='Vous ne pouvez pas éditer ce dossier';
GO.email.lang.cantDeleteInboxFolder='Vous ne pouvez pas supprimer le dossier \'Boite de réception\'';
GO.email.lang.enterFolderName='Saisissez le nom du dossier :';
GO.email.lang.addFolder='Ajouter un dossier';
GO.email.lang.to='A';
GO.email.lang.downloadAllAsZip='Télécharger toutes les pièces jointes dans un fichier ZIP';
GO.email.lang.body='Corps';
GO.email.lang.recievedBefore='Reçu avant';
GO.email.lang.recievedSince='Reçu depuis';
GO.email.lang.answered='Répondu';
GO.email.lang.unanswered='Non répondu';
GO.email.lang.viewed='Vu';
GO.email.lang.outgoingMail='Messages sortant';
GO.email.lang.encryption='Cryptage';
GO.email.lang.type='Type';
GO.email.lang.noEncryption='Pas de cryptage';
GO.email.lang.noAccountTitle='Pas de compte';
GO.email.lang.priority='Priorité';
GO.email.lang.read='Lu';
GO.email.lang.NA='N/R';
GO.email.lang.emptyFolder='Vider ce dossier';
GO.email.lang.emptyFolderConfirm='Etes-vous sûr de vouloir <font style="color: red;">VIDER</font> le dossier <b>\'{name}\'</b> ?';
GO.email.lang.addUnknownRecipients='Ajouter les destinataires inconnus';
GO.email.lang.addUnknownRecipientsText='Vous venez juste d\'envoyer un message à un destinataire qui ne figure pas dans votre carnet d`adresses. Cliquez sur le nom si vous voulez l\'ajouter ou fermez cette fenêtre.';
GO.email.lang.attachFilesPC='Ajouter depuis votre ordinateur';
GO.email.lang.attachFilesGO='Ajouter depuis Group-Office';
GO.email.lang.renameFolder='Renommer ce dossier';
GO.email.lang.vacation='Réponse automatique';
GO.email.lang.vacationActive='Activer la réponse automatique';
GO.email.lang.vacationSubject='Sujet';
GO.email.lang.vacationBody='Corps';
GO.email.lang.addToRecipients = 'Ajouter aux destinataires';
GO.email.lang.addToCC = 'Ajouter en copie';
GO.email.lang.addToBCC = 'Ajouter en copie cachée';
GO.email.lang.viewSource='Voir la source du message';
GO.email.lang.sendNotification='L\'expéditeur de ce message a demandé une notification de lecture : %s. Voulez-vous envoyer la notification maintenant ?';
GO.email.lang.searchOnSender='Afficher les messages';
GO.email.lang.blocked = '{blocked_images} Afin de protéger votre vie privée, l\'affichage des images distantes a été bloqué.';
GO.email.lang.unblock = 'Cliquez ici pour afficher les images bloquées';
GO.email.lang.loadEmailFirst = 'Pour utiliser cette fonctionnalité vous devez tout d\'abord cliquer sur l\'onglet e-mail';
GO.email.lang.confirmEmptySubject='Vous n\'avez pas spécifié de sujet à votre message.\nVoulez-vous quand même l\'envoyer ?';
GO.email.lang.usage='Espace utilisé';
GO.email.lang.searchGO='Recherche globale';
GO.email.lang.toggleWindowPosition = 'Permuter l\'affichage des messages';
GO.email.lang.closeUploadDialog='Veuillez fermer cette fenêtre ou attendre la fin du transfert';
GO.email.lang.signature='Signature';
GO.email.defaultProgram='Programme de messagerie par défaut';
GO.email.defaultProgramInstructions ='<p>Pour définir Group-Office comme programme de messagerie par défaut, veuillez <a class="normal-link" href="http://www.group-office.com/wiki/E-mail#Set_Group-Office_as_your_default_e-mail_client" target="_blank">lire ces instructions</a>.</p><p>Si vous utilisez Microsoft Windows, vous devez télécharger et exécuter <a class="normal-link" href="{url}">ce fichier</a></p>';
GO.email.lang.htmlMarkup = 'Rédiger en HTML';
GO.email.lang.confirmLostChanges = 'Changer d\'éditeur entraîne la perte du texte de votre message !\nVoulez-vous continuer ?';
/* table: em_aliases */
GO.email.lang.alias="Paramètres de l'identité";
GO.email.lang.aliases="Identités multiples";
GO.email.lang.accountId="ID du compte";
GO.email.lang.email="E-mail";
GO.email.lang.signature="Signature";
GO.email.lang.manageAliases='Gérer les identités...';
GO.email.lang.addSendersTo='Nouveau message à l\'expéditeur';
GO.email.lang.defaultTemplate='Sélectionner ce modèle par défaut';
GO.email.lang.moving='Déplacement...';
GO.email.lang.orderFilters='Vous pouvez déplacer l\'ordre des filtres en cliquant / déplaçant.';
GO.email.lang.orderAccounts='Vous pouvez déplacer l\'ordre des comptes en cliquant / déplaçant.';
GO.email.lang.groups='Groupes';
GO.email.lang.showUnread='Afficher les messages non lus';
GO.email.lang.searchFrom='Expéditeur';
GO.email.lang.searchTo='Destinataire';
GO.email.lang.searchCC='Destinataire (CC)';
GO.email.lang.youHaveNewMails = 'Vous avez {new} nouveau(x) message(s)';
GO.email.lang.anyField='Tous les champs';

GO.email.lang.selectFolderRename='Veuillez sélectionner un dossier a renommer';
GO.email.lang.cantRenameInboxFolder='Vous ne pouvez pas renommer le dossier Boite de réception';
GO.email.lang.replaceEmailText='Trois adresses email sont déjà assignées a ce contact. Vous pouvez remplacer une adresse existante ci-dessous en cliquant sur l\'adresse que vous souhaitez remplacer.';
GO.email.lang.skipUnknownRecipientsAction='Ne pas afficher cette fenêtre la prochaine fois';
GO.email.lang.skipUnknownRecipients='Ne pas afficher de boite de dialogue pour les destinaires inconnus';
GO.email.lang.alwaysRequestNotification='Toujours demander un accusé de réception';
GO.email.lang.alwaysRespondToNotifications='Toujours répondre aux accusés de réception';
GO.email.lang.icalendarUpdateEvent='Mettre à jour le rendez vous';
GO.email.lang.icalendarDeleteEvent='Supprimer le rendez-vous';
GO.email.lang.icalendarAcceptInvitation='Accepter';
GO.email.lang.icalendarDeclineInvitation='Décliner';
GO.email.lang.icalendarTentativeInvitation='Accepter sous réserve';
GO.email.lang.icalendarEventUpdated='Le rendez-vous a été mis à jour.';
GO.email.lang.icalendarEventCreated='Le rendez-vous a été créé.';
GO.email.lang.icalendarEventDeleted='Le rendez-vous a été supprimé.';
GO.email.lang.icalendarInvitationDeclined='L\'invitation a été déclinée.';
GO.email.lang.icalendarDeleteEventConfirm='Êtes vous sur de vouloir supprimer ce rendez-vous ?';
GO.email.lang.sending='Envoi en cours...';

GO.email.lang.defaultFontSize = 'Taille de la police par défaut';
GO.email.lang.shareFolder = 'Partager';
GO.email.lang.readPerm='Lire';
GO.email.lang.writePerm='Ecrire';
GO.email.lang.deletePerm='supprimer';
GO.email.lang.createMailboxPerm='Créer la boite de messagerie';
GO.email.lang.deleteMailboxPerm='Supprimer la boite de messagerie';
GO.email.lang.adminPerm='Administrer';

GO.email.lang.deleteOldMails = 'Supprimer les anciens messages';
GO.email.lang.deleteOldMailsInstructions = 'Sélectionnez une date. Si vous cliquez sur OK, tous les messages avec une date antérieure dans le dossier sélectionné seront supprimés.';
GO.email.lang.folder = 'Dossier';
GO.email.lang.deleteOldMailsSure1 = 'Cette action est irréversible. Êtes-vous sûr de vouloir supprimer tous les messages remplissant la condition de date selectionnée ';
GO.email.lang.deleteOldMailsSure2 = '?'
GO.email.lang.nDeletedMailsTxt = 'Le nombre de messages supprimés est';
GO.email.lang.deletingEmails = 'Suppression des messages...';
GO.email.lang.everythingBefore = 'Tous les messages avant';
GO.email.lang.alsoChildren = 'Appliquer également cette condition aux sous-dossiers.';
GO.email.lang.emailFiles='Envoyer par email';
